@@ -10,7 +10,7 @@ require      Exporter;
 our @ISA = qw (Exporter);
 our @EXPORT = qw (baseconfigure verbosity freezeverbosity dumper);
 
-our $VERSION = "1.22";
+our $VERSION = "1.23";
 
 $Baseobject::directfeedback=0; # for downward compatibility
 $Baseobject::quickdeath=0;
@@ -217,7 +217,7 @@ sub checkneeds {
 		}
 	}
 	
-	$self->error("missing requirement(s): ", join(', ', @missing));
+	$self->error("missing requirement(s): ", join(', ', @missing)) if @missing;
 
 	return $self;
 }
